0.2.0
-----

- Add next page function

0.1.3
-----

- BugFix: Remove Translation from the exception

0.1.2
-----

- BugFix: Compare with the correct var

0.1.1
-----

- BugFix: Remove django import

0.1.0
-----

- Initial release
